==> huaweicloudsdkdws-3.1.99-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/show_database_authority_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDatabaseAuthorityResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'authorities': 'list[ObjectAuthority]'
    }

    attribute_map = {
        'authorities': 'authorities'
    }

    def __init__(self, authorities=None):
        """ShowDatabaseAuthorityResponse

        The model defined in huaweicloud sdk

        :param authorities: 对象权限集合
        :type authorities: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        
        super(ShowDatabaseAuthorityResponse, self).__init__()

        self._authorities = None
        self.discriminator = None

        if authorities is not None:
            self.authorities = authorities

    @property
    def authorities(self):
        """Gets the authorities of this ShowDatabaseAuthorityResponse.

        对象权限集合

        :return: The authorities of this ShowDatabaseAuthorityResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        return self._authorities

    @authorities.setter
    def authorities(self, authorities):
        """Sets the authorities of this ShowDatabaseAuthorityResponse.

        对象权限集合

        :param authorities: The authorities of this ShowDatabaseAuthorityResponse.
        :type authorities: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        self._authorities = authorities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDatabaseAuthorityResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/show_database_authority_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDatabaseAuthorityResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'authorities': 'list[ObjectAuthority]'
    }

    attribute_map = {
        'authorities': 'authorities'
    }

    def __init__(self, authorities=None):
        r"""ShowDatabaseAuthorityResponse

        The model defined in huaweicloud sdk

        :param authorities: 对象权限集合
        :type authorities: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        
        super(ShowDatabaseAuthorityResponse, self).__init__()

        self._authorities = None
        self.discriminator = None

        if authorities is not None:
            self.authorities = authorities

    @property
    def authorities(self):
        r"""Gets the authorities of this ShowDatabaseAuthorityResponse.

        对象权限集合

        :return: The authorities of this ShowDatabaseAuthorityResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        return self._authorities

    @authorities.setter
    def authorities(self, authorities):
        r"""Sets the authorities of this ShowDatabaseAuthorityResponse.

        对象权限集合

        :param authorities: The authorities of this ShowDatabaseAuthorityResponse.
        :type authorities: list[:class:`huaweicloudsdkdws.v2.ObjectAuthority`]
        """
        self._authorities = authorities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDatabaseAuthorityResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
